Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5842)

Unified Diff: chrome/browser/spellchecker/spellcheck_message_filter_platform.h

Issue 1230933002: Patch 3.1: Refactored spellcheck_message_filter to be generic (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@platform_flag
Patch Set: Updated gn build variable to match gyp side Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/spellchecker/spellcheck_message_filter_platform.h
diff --git a/chrome/browser/spellchecker/spellcheck_message_filter_mac.h b/chrome/browser/spellchecker/spellcheck_message_filter_platform.h
similarity index 78%
rename from chrome/browser/spellchecker/spellcheck_message_filter_mac.h
rename to chrome/browser/spellchecker/spellcheck_message_filter_platform.h
index 18129b352d208d97bc920052024f396ab56d4732..a632112734b42457585b725c12f53d7b976d3a3a 100644
--- a/chrome/browser/spellchecker/spellcheck_message_filter_mac.h
+++ b/chrome/browser/spellchecker/spellcheck_message_filter_platform.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_SPELLCHECKER_SPELLCHECK_MESSAGE_FILTER_MAC_H_
-#define CHROME_BROWSER_SPELLCHECKER_SPELLCHECK_MESSAGE_FILTER_MAC_H_
+#ifndef CHROME_BROWSER_SPELLCHECKER_SPELLCHECK_MESSAGE_FILTER_PLATFORM_H_
+#define CHROME_BROWSER_SPELLCHECKER_SPELLCHECK_MESSAGE_FILTER_PLATFORM_H_
#include <map>
@@ -12,10 +12,10 @@
#include "content/public/browser/browser_message_filter.h"
// A message filter implementation that receives
-// the Mac-specific spell checker requests from SpellCheckProvider.
-class SpellCheckMessageFilterMac : public content::BrowserMessageFilter {
+// the platform-specific spell checker requests from SpellCheckProvider.
+class SpellCheckMessageFilterPlatform : public content::BrowserMessageFilter {
public:
- explicit SpellCheckMessageFilterMac(int render_process_id);
+ explicit SpellCheckMessageFilterPlatform(int render_process_id);
// BrowserMessageFilter implementation.
void OverrideThreadForMessage(const IPC::Message& message,
@@ -31,9 +31,9 @@ class SpellCheckMessageFilterMac : public content::BrowserMessageFilter {
private:
friend class TestingSpellCheckMessageFilter;
- friend class SpellcheckMessageFilterMacTest;
+ friend class SpellcheckMessageFilterPlatformMacTest;
- ~SpellCheckMessageFilterMac() override;
+ ~SpellCheckMessageFilterPlatform() override;
void OnCheckSpelling(const base::string16& word, int route_id, bool* correct);
void OnFillSuggestionList(const base::string16& word,
@@ -54,7 +54,7 @@ class SpellCheckMessageFilterMac : public content::BrowserMessageFilter {
// A JSON-RPC client that calls the Spelling service in the background.
scoped_ptr<SpellingServiceClient> client_;
- DISALLOW_COPY_AND_ASSIGN(SpellCheckMessageFilterMac);
+ DISALLOW_COPY_AND_ASSIGN(SpellCheckMessageFilterPlatform);
};
-#endif // CHROME_BROWSER_SPELLCHECKER_SPELLCHECK_MESSAGE_FILTER_MAC_H_
+#endif // CHROME_BROWSER_SPELLCHECKER_SPELLCHECK_MESSAGE_FILTER_PLATFORM_H_

Powered by Google App Engine
This is Rietveld 408576698